=========================================================
JukeDj
=========================================================

.. image:: http://img.shields.io/pypi/v/jukedj.png
    :target: https://pypi.python.org/pypi/jukedj

.. image:: http://img.shields.io/pypi/dm/jukedj.png
    :target: https://pypi.python.org/pypi/jukedj

.. image:: http://img.shields.io/pypi/l/jukedj.png
    :target: https://pypi.python.org/pypi/jukedj




Django app for models used in the JukeboxPipeline.


Documentation
-------------

The documentation can be found under http://pythonhosted.org/jukedj.
